// A simple compilable script for demonstrating the Geometry service.
// to compile and run, execute '.x example.cxx' from the ROOT command line.
 
#include "Geometry.h"
#include "example_readValues.h"

#include <iostream>
#include <map>
#include <string>

#include "TROOT.h"
#include "TSystem.h"

void example_draw(){
  cout << "Running the main program example_draw" << endl;
  
  // create the geometry service
  // see Geometry.h
  Geometry* geo = new Geometry("geo/hec_geo_050424.dat", "geo/emec_geo_050424.dat", "geo/global_geo_040506.dat");

  // read from a file a offlineID keyed map of float values to plot
  map<int, float> valuesMap = example_readValues("example_values.dat");

  // draw 2D colour maps of these values
  // see Geometry.h for options
  geo->draw2DHec(valuesMap, 0, false, 0., 0., "values read from file", -2);
  geo->draw2DEmec(valuesMap, 0, false, 0., 0., "values read from file", -2);

  // draw in more details
  // see Geometry.h for options
  //  geo->draw2DHecDetail(valuesMap, 0, false, 0., 0., "values read from file", -2);
  //  geo->draw2DEmecDetail(valuesMap, 0, false, 0., 0., "values read from file", -2);

  // draw 2D colour maps of the volume of all the hec cells
  // first get a offlineID keyed map of febno
  map<int, int> hec_OfflineIDToFebnoMap = geo->hec_OfflineIDToFebnoMap();
  // prepare offlineID keyed map of hec volumes
  map<int, float> hecVMap;
  // for each available offlineID
  // 1- find the correspondinf febno (beam test internal cell id)
  // 2- find the volume
  for (map<int, int>::iterator it = hec_OfflineIDToFebnoMap.begin(); it != hec_OfflineIDToFebnoMap.end(); ++it) {
    int offlineID = it->first;
    int febno = it->second;
    float V = geo->hec_Volume(febno);  // in cm^3
    hecVMap[offlineID] = V;
  }
  geo->draw2DHec(hecVMap, 0, false, 0., 0., "cell volume (cm^3)", -2);

  // draw 2D colour maps of the volume of all the emec cells
  // first get a offlineID keyed map of febno
  map<int, int> emec_OfflineIDToFebnoMap = geo->emec_OfflineIDToFebnoMap();
  // prepare offlineID keyed map of hec volumes
  map<int, float> emecVMap;
  // for each available offlineID
  // 1- find the correspondinf febno (beam test internal cell id)
  // 2- find the volume
  for (map<int, int>::iterator it = emec_OfflineIDToFebnoMap.begin(); it != emec_OfflineIDToFebnoMap.end(); ++it) {
    int offlineID = it->first;
    int febno = it->second;
    float V = geo->emec_Volume(febno);  // in cm^3
    emecVMap[offlineID] = V;
  }
  geo->draw2DEmec(emecVMap, 0, false, 0., 0., "cell volume (cm^3)", -2);

}
